@@ -252,6 +252,11 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".pre-commit-config.yaml" => '\u{f06e2}',       // 󰛢
     ".prettierignore"     => '\u{e6b4}',            // 
     ".prettierrc"         => '\u{e6b4}',            // 
+    ".prettierrc.json"    => '\u{e6b4}',            // 
+    ".prettierrc.json5"   => '\u{e6b4}',            // 
+    ".prettierrc.toml"    => '\u{e6b4}',            // 
+    ".prettierrc.yaml"    => '\u{e6b4}',            // 
+    ".prettierrc.yml"     => '\u{e6b4}',            // 
     ".parentlock"         => Icons::LOCK,           // 
     ".profile"            => Icons::SHELL,          // 󱆃
     ".pylintrc"           => Icons::CONFIG,         // 
